@@ -242,7 +242,7 @@ while (status == 1) {
 	mvwaddstr(mid_w,3,2, "from a database will be sent. After each callsign,");
 	mvwaddstr(mid_w,4,2, "enter what you have heard. If you copied correctly,");
 	mvwaddstr(mid_w,5,2, "full points are credited and the speed increases by");
-	mvwaddstr(mid_w,6,2, "10 LpM, otherwise the speed decreases and only a ");
+	mvwaddstr(mid_w,6,2, "2 WpM -- otherwise the speed decreases and only a ");
 	mvwaddstr(mid_w,7,2, "fraction of the points, depending on the number of");
 	mvwaddstr(mid_w,8,2, "errors is credited.");
 	mvwaddstr(mid_w,10,2, "F6 repeats a callsign once, F10 quits.");
@@ -332,7 +332,7 @@ while (status == 1) {
 		}
 
 		mvwprintw(bot_w,1,1,"                                      ");
-		mvwprintw(bot_w, 1, 1, "%2d", callnr);	
+		mvwprintw(bot_w, 1, 1, "%2d/50", callnr);	
 		wrefresh(bot_w);	
 		tmp[0]='\0';
 
@@ -342,12 +342,12 @@ while (status == 1) {
 		j = pthread_create(&cwthread, NULL, morse, calls[i]);	
 		thread_fail(j);		
 		
-		if (readcall(bot_w, 1, 5, input) > 4) {	/* F5 or F6 was pressed */
+		if (readcall(bot_w, 1, 8, input) > 4) {	/* F5 or F6 was pressed */
 			/* wait for old cwthread to finish, then send call again */
 			pthread_join(cwthread, NULL);
 			j = pthread_create(&cwthread, NULL, morse, calls[i]);	
 			thread_fail(j);		
-			while (readcall(bot_w, 1, 5, input) > 4) {
+			while (readcall(bot_w, 1, 8, input) > 4) {
 				/* pressing F6 again has no effect */
 			}
 		}
@@ -542,8 +542,10 @@ static int readcall(WINDOW *win, int y, int x, char * call) {
 	curs_set(TRUE);
 	
 	while ((c = getch()) != '\n') {
-		
-		if ((isalnum(c) || c == '/') && strlen(call) < 14) {
+
+		if (((c > 64 && c < 91) || (c > 96 && c < 123) || (c > 47 && c < 58)
+					 || c == '/') && strlen(call) < 14) {
+	
 			call[strlen(call)+1]='\0';
 			c = toupper(c);
 			if (mode == 1) {						/* insert */
@@ -574,6 +576,12 @@ static int readcall(WINDOW *win, int y, int x, char * call) {
 		else if (c == KEY_RIGHT && p < strlen(call)) {
 			p++;
 		}
+		else if (c == KEY_HOME) {
+			p = 0;
+		}
+		else if (c == KEY_END) {
+			p = strlen(call);
+		}
 		else if (c == KEY_IC) {						/* INS/OVR */
 			if (mode == 1) { 
 				mode = 0; 
@@ -976,7 +984,7 @@ static void *morse(void *arg) {
 static int tonegen (int freq, int len, int waveform) {
 	int x=0;
 	int out;
-	double val;
+	double val=0;
 	/* convert len from milliseconds to samples, determine rise/fall time */
 	len = (int) (samplerate * (len/1000.0));
 	for (x=0; x < len-1; x++) {
@@ -1280,6 +1288,7 @@ static int statistics () {
 
 		int time = 0;
 		int score = 0;
+		int count= 0;
 
 		FILE *fh;
 		FILE *fh2;
@@ -1295,16 +1304,23 @@ static int statistics () {
 		}
 
 		fprintf(fh2, "set yrange [0:]\nset xlabel \"Date/Time\"\n"
+					"set title \"QRQ scores for %s. Press 'q' to "
+					"close this window.\"\n"
 					"set ylabel \"Score\"\nset xdata time\nset "
-					" timefmt \"%%s\"\n"
-					"plot \"-\" using 1:2 title \"%s\"\n", mycall);
+					" timefmt \"%%s\"\n "
+					"plot \"-\" using 1:2 title \"\"\n", mycall);
 
 		while ((feof(fh) == 0) && (fgets(line, 80, fh) != NULL)) {
 				if ((strstr(line, mycall) != NULL)) {
+					count++;
 					sscanf(line, "%*s %d %*d %d", &score, &time);
 					fprintf(fh2, "%d %d\n", time, score);
 				}
 		}
+
+		if (!count) {
+			fprintf(fh2, "0 0\n");
+		}
 		
 		fprintf(fh2, "end\npause 10000");
 
